=================
Fortran man pages
=================
.. image:: https://img.shields.io/pypi/v/fortranman.svg
   :alt: Fortran man pages on the Python Package Index
   :target: https://pypi.python.org/pypi/fortranman

.. image:: https://img.shields.io/travis/alejandrogallo/fortranman.svg
   :alt: Travis Continuous Integration
   :target: https://travis-ci.org/alejandrogallo/fortranman
.. image:: https://coveralls.io/repos/github/alejandrogallo/fortranman/badge.svg?branch=master
   :alt: Coveralls
   :target: https://coveralls.io/github/alejandrogallo/fortranman?branch=master
.. image:: https://img.shields.io/badge/License-GPL%20v3-green.svg
   :alt: GPL v3 License
   :target: https://www.gnu.org/licenses/gpl-3.0

Man pages for fortran

Development of Fortran man pages happens on `Github`_.


Installation
------------
To install the latest released version of Fortran man pages, run this command in your terminal:

.. code-block:: console

    $ pip install fortranman

This is the preferred method to install Fortran man pages, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


To install the latest development version of Fortran man pages from `Github`_.

.. code-block:: console

    $ pip install git+https://github.com/alejandrogallo/fortranman.git@master#egg=fortranman

.. _Github: https://github.com/alejandrogallo/fortranman

Usage
-----

To use Fortran man pages in a project::

    import fortranman
